From 688baaa086fc840389978364fca2df08c374806f Mon Sep 17 00:00:00 2001
From: Alexander Kissinger <alexander.kissinger@iws.uni-stuttgart.de>
Date: Thu, 10 May 2012 09:57:55 +0000
Subject: [PATCH] new naming convention 3p3cni

git-svn-id: svn://svn.iws.uni-stuttgart.de/DUMUX/dumux/trunk@8288 2fb0f335-1f38-0410-981e-8018bf24f1b0
---
 dumux/boxmodels/3p3cni/3p3cnifluxvariables.hh | 30 +++++++++----------
 dumux/boxmodels/3p3cni/3p3cnilocalresidual.hh |  8 ++---
 .../boxmodels/3p3cni/3p3cnivolumevariables.hh | 30 +++++++++----------
 3 files changed, 34 insertions(+), 34 deletions(-)

diff --git a/dumux/boxmodels/3p3cni/3p3cnilocalresidual.hh b/dumux/boxmodels/3p3cni/3p3cnilocalresidual.hh
index e35af2ac99..5efcce0853 100644
--- a/dumux/boxmodels/3p3cni/3p3cnilocalresidual.hh
+++ b/dumux/boxmodels/3p3cni/3p3cnilocalresidual.hh
@@ -88,14 +88,14 @@ public:
      * The result should be averaged over the volume (e.g. phase mass
      * inside a sub control volume divided by the volume)
      *
-     *  \param result The storage of the conservation quantitiy (mass or energy) within the sub-control volume
+     *  \param storage The storage of the conservation quantitiy (mass or energy) within the sub-control volume
      *  \param scvIdx The SCV (sub-control-volume) index
      *  \param usePrevSol Evaluate function with solution of current or previous time step
      */
-    void computeStorage(PrimaryVariables &result, int scvIdx, bool usePrevSol) const
+    void computeStorage(PrimaryVariables &storage, const int scvIdx, bool usePrevSol) const
     {
         // compute the storage term for phase mass
-        ParentType::computeStorage(result, scvIdx, usePrevSol);
+        ParentType::computeStorage(storage, scvIdx, usePrevSol);
 
         // if flag usePrevSol is set, the solution from the previous
         // time step is used, otherwise the current solution is
@@ -119,7 +119,7 @@ public:
         Scalar heatCap = vertDat.heatCapacity();
         Scalar poro = vertDat.porosity();
 
-        result[energyEqIdx] = temp*heatCap
+        storage[energyEqIdx] = temp*heatCap
             + poro * (gdens*gInEnerg*gsat
                       + wdens*wInEnerg*wsat
                       + ndens*nInEnerg*nsat);
diff --git a/dumux/boxmodels/3p3cni/3p3cnifluxvariables.hh b/dumux/boxmodels/3p3cni/3p3cnifluxvariables.hh
index 1750eca01e..bb6b1aa4f6 100644
--- a/dumux/boxmodels/3p3cni/3p3cnifluxvariables.hh
+++ b/dumux/boxmodels/3p3cni/3p3cnifluxvariables.hh
@@ -70,7 +70,7 @@ class ThreePThreeCNIFluxVariables : public ThreePThreeCFluxVariables<TypeTag>
 
     typedef typename GET_PROP_TYPE(TypeTag, FVElementGeometry) FVElementGeometry;
 
-    typedef Dune::FieldVector<CoordScalar, dimWorld> Vector;
+    typedef Dune::FieldVector<CoordScalar, dim> DimVector;
 
 public:
     /*
@@ -78,43 +78,43 @@ public:
      *
      * \param problem The problem
      * \param element The finite element
      * \param elemGeom The finite-volume geometry in the box scheme
      * \param faceIdx The local index of the SCV (sub-control-volume) face
      * \param elemDat The volume variables of the current element
      * \param onBoundary A boolean variable to specify whether the flux variables
      * are calculated for interior SCV faces or boundary faces, default=false
      */
     ThreePThreeCNIFluxVariables(const Problem &problem,
                                 const Element &element,
-                                const FVElementGeometry &elemGeom,
-                                int scvfIdx,
-                                const ElementVolumeVariables &elemDat,
+                                const FVElementGeometry &fvGeometry,
+                                const int faceIdx,
+                                const ElementVolumeVariables &elemVolVars,
                                 const bool onBoundary = false)
-        : ParentType(problem, element, elemGeom, scvfIdx, elemDat, onBoundary)
+        : ParentType(problem, element, fvGeometry, faceIdx, elemVolVars, onBoundary)
     {
         // calculate temperature gradient using finite element
         // gradients
-        Vector temperatureGrad(0);
-        Vector tmp(0.0);
-        for (int vertIdx = 0; vertIdx < elemGeom.numFAP; vertIdx++)
+        DimVector temperatureGrad(0);
+        DimVector tmp(0.0);
+        for (int vertIdx = 0; vertIdx < fvGeometry.numFAP; vertIdx++)
         {
             tmp = this->face().grad[vertIdx];
 
             // index for the element volume variables 
             int volVarsIdx = this->face().fapIndices[vertIdx];
 
-            tmp *= elemDat[volVarsIdx].temperature();
+            tmp *= elemVolVars[volVarsIdx].temperature();
             temperatureGrad += tmp;
         }
 
         // The spatial parameters calculates the actual heat flux vector
-        problem.spatialParameters().matrixHeatFlux(tmp,
+        problem.spatialParams().matrixHeatFlux(tmp,
                                                    *this,
-                                                   elemDat,
+                                                   elemVolVars,
                                                    temperatureGrad,
                                                    element,
-                                                   elemGeom,
-                                                   scvfIdx);
+                                                   fvGeometry,
+                                                   faceIdx);
         // project the heat flux vector on the face's normal vector
         normalMatrixHeatFlux_ = tmp*this->face().normal;
     }
@@ -78,43 +78,43 @@ public:
      * \param problem The problem
      * \param element The finite element
-     * \param elemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param faceIdx The local index of the SCV (sub-control-volume) face
@@ -78,43 +78,43 @@ public:
      * \param faceIdx The local index of the SCV (sub-control-volume) face
-     * \param elemDat The volume variables of the current element
+     * \param elemVolVars The volume variables of the current element
      * \param onBoundary A boolean variable to specify whether the flux variables
      * are calculated for interior SCV faces or boundary faces, default=false
diff --git a/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh b/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
index 902e8c8fe2..2e1d3ee574 100644
--- a/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
+++ b/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
@@ -72,26 +72,26 @@ public:
     /*!
      * \brief Update all quantities for a given control volume.
      *
      * \param sol The solution primary variables
      * \param problem The problem
      * \param element The element
      * \param elemGeom Evaluate function with solution of current or previous time step
      * \param vertIdx The local index of the SCV (sub-control volume)
      * \param isOldSol Evaluate function with solution of current or previous time step
      */
-    void update(const PrimaryVariables &sol,
+    void update(const PrimaryVariables &priVars,
                 const Problem &problem,
                 const Element &element,
-                const FVElementGeometry &elemGeom,
-                int vertIdx,
+                const FVElementGeometry &fvGeomtry,
+                const int scvIdx,
                 bool isOldSol)
     {
         // vertex update data for the mass balance
-        ParentType::update(sol,
+        ParentType::update(priVars,
                            problem,
                            element,
-                           elemGeom,
-                           vertIdx,
+                           fvGeomtry,
+                           scvIdx,
                            isOldSol);
 
         typename FluidSystem::ParameterCache paramCache;
@@ -137,8 +137,8 @@ protected:
     static Scalar temperature_(const PrimaryVariables &primaryVars,
                                const Problem& problem,
                                const Element &element,
-                               const FVElementGeometry &elemGeom,
-                               int scvIdx)
+                               const FVElementGeometry &fvGeomtry,
+                               const int scvIdx)
     {
         return primaryVars[temperatureIdx];
     }
@@ -146,22 +146,22 @@ protected:
     /*!
      * \brief Update all quantities for a given control volume.
      *
      * \param sol The solution primary variables
      * \param problem The problem
      * \param element The element
      * \param elemGeom Evaluate function with solution of current or previous time step
      * \param scvIdx The local index of the SCV (sub-control volume)
      * \param isOldSol Evaluate function with solution of current or previous time step
      */
-    void updateEnergy_(const PrimaryVariables &sol,
+    void updateEnergy_(const PrimaryVariables &priVars,
                        const Problem &problem,
                        const Element &element,
-                       const FVElementGeometry &elemGeom,
-                       int scvIdx,
+                       const FVElementGeometry &fvGeomtry,
+                       const int scvIdx,
                        bool isOldSol)
     {
         // copmute and set the heat capacity of the solid phase
-        heatCapacity_ = problem.spatialParameters().heatCapacity(element, elemGeom, scvIdx);
+        heatCapacity_ = problem.spatialParams().heatCapacity(element, fvGeomtry, scvIdx);
         Valgrind::CheckDefined(heatCapacity_);
     };
 
@@ -72,26 +72,26 @@ public:
      * \brief Update all quantities for a given control volume.
      *
-     * \param sol The solution primary variables
+     * \param priVars The solution primary variables
      * \param problem The problem
      * \param element The element
@@ -146,22 +146,22 @@ protected:
      * \brief Update all quantities for a given control volume.
      *
-     * \param sol The solution primary variables
+     * \param priVars The solution primary variables
      * \param problem The problem
      * \param element The element
@@ -146,22 +146,22 @@ protected:
      * \param problem The problem
      * \param element The element
-     * \param elemGeom Evaluate function with solution of current or previous time step
+     * \param fvGeomtry Evaluate function with solution of current or previous time step
      * \param scvIdx The local index of the SCV (sub-control volume)
      * \param isOldSol Evaluate function with solution of current or previous time step
-- 
GitLab